/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef __DB_LOG_H
#define __DB_LOG_H 1

#include <sys/time.h>
#include <stdint.h>
#include <string>
#include <map>

typedef struct sqlite3 sqlite3;

// update the call log database end_time field
class DBLog
{
public:
	DBLog();
	~DBLog();
	// opens the database
	bool Open();
	void CallSetup(const char *path, const char *stream, const char *media,
		uint32_t ui1, uint32_t ui2, bool b);
	void CallLog(int id, const char *protocol, const char *contact,
		const char *str3, const char *str4, const char *type);
	void CallEnded(const char *stream, int unknown);
	static void SetVerbose(int v) { Verbose=v; }
	static int GetVerbose() { return Verbose; }
private:
	static int Verbose;
	sqlite3 *Db;
	struct Call
	{
		int id;
		struct timeval storage_time, start_time, end_time;
		sqlite3 *Db; // for use in the callback
	};
	typedef std::map<std::string, Call> StreamIdType;
	StreamIdType StreamId;
	// Store the stream from CallSetup for CallLog, assuming CallLog
	// follows the CallSetup for the same stream,
	std::string LastSetupStream;

	// is called once per row returned in exec
	static int Callback(void *userdata, int columns, char **value,
		char **header);
	void Status();
};

#endif // __DB_LOG_H
