/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include <QtGui/QApplication>
#include <QDeclarativeContext>
#include <QDeclarativeEngine>
#include <QDBusConnection>
#include <QUrl>
#include <QGLWidget>
#include <QMenuBar>
#include <iostream>
#include <unistd.h>
#include "StackWindow.h"
#include "MinuteMonitor.h"
#include "DBMonitor.h"

using namespace std;

MinuteMonitor::MinuteMonitor()
{
	QMenuBar *menubar=new QMenuBar(this);
	menubar->addAction("Reload QML", this, SLOT(ReloadQML()));
	menubar->addAction("Settings", this, SIGNAL(Settings()));
	menubar->addAction("About", this, SIGNAL(About()));

	if(!Db.Open())
		exit(1);
	Db.SetPeriod(time(NULL));
	if(!Db.Load())
		exit(1);
	rootContext()->setContextProperty("store", &Db);
	rootContext()->setContextProperty("labelModel", Db.Labels());
	rootContext()->setContextProperty("minuteMonitor", this);

	// Try the local file first (useful for development), and if
	// it isn't available try the compiled in resources.
	const char *qml_main="qml/MinuteMonitor.qml";
	if(!access(qml_main, R_OK))
	{
		setSource(QUrl::fromLocalFile("qml/MinuteMonitor.qml"));
	}
	if(status() != QDeclarativeView::Ready)
	{
		setSource(QUrl("qrc:qml/MinuteMonitor.qml"));
	}
	if(status() != QDeclarativeView::Ready)
	{
		cout << "QML script not loaded\n";
		exit(1);
	}

	QDBusConnection session=QDBusConnection::sessionBus();
	// Qt doesn't allow filtering on member='call_ended' verify in the
	// callback.
	session.connect("", "/com/nokia/policy/telephony",
		"com.nokia.policy.telephony", "", this, SLOT(CallEnded()));

	StatusDelay.setSingleShot(true);
	StatusDelay.setInterval(1000);
	// When the alarm goes off, first load the database, then emit
	// the Updated signal, but only that object and derived classes
	// can emit the signal, but a Qt signal can.  They are called in
	// order, so this will work.
	connect(&StatusDelay, SIGNAL(timeout()), this, SLOT(UpdateStatus()));
	connect(&StatusDelay, SIGNAL(timeout()), &Db, SIGNAL(Updated()));
}

/*
void MinuteMonitor::keyPressEvent(QKeyEvent *event)
{
	if(!event->isAutoRepeat())
	{
		if(event->key()==Qt::Key_R && event->modifiers() ==
			Qt::ControlModifier)
		{
		}
	}
}
*/

void MinuteMonitor::ReloadQML()
{
	// required to force a reload
	engine()->clearComponentCache();
	setSource(source());
	Reloaded();
}

void MinuteMonitor::CallEnded()
{
	Msg=message();
	if(Msg.member() == "call_ended")
		StatusDelay.start();
}

void MinuteMonitor::UpdateStatus()
{
	Db.Load();
}

int main(int argc, char *argv[])
{
	QApplication a(argc, argv);

	MinuteMonitor *view=new MinuteMonitor;
	view->setResizeMode(QDeclarativeView::SizeRootObjectToView);
	// OpenGL display
	if(argv[1] && *argv[1] == 'g')
	{
		QGLFormat format = QGLFormat::defaultFormat();
		format.setSampleBuffers(false);
		// make QmlView use OpenGL ES2 backend.
		QGLWidget *glWidget = new QGLWidget(format);
		glWidget->setAutoFillBackground(false);
		view->setViewport(glWidget);
	}
	StackWindow stack(view);
	stack.show();

	return a.exec();
}
