/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _STACK_WINDOW_H
#define _STACK_WINDOW_H 1
#include <QWidget>

class MinuteMonitor;
class QShowEvent;
class QHideEvent;
class QResizeEvent;

// Maemo 5's window manager requires top level windows to replace the close
// button with the back arrow.  QML can't create a new top level window by
// creating additional items, because they all part of one window.
// Support stacking windows by creating top level widgets and reparanting
// the declarative view to avoid having to create multiple of them.
class StackWindow : public QWidget
{
	Q_OBJECT
public:
	StackWindow(MinuteMonitor *view, QWidget *parent=NULL);
	Q_INVOKABLE void PushStack();
protected:
	virtual void hideEvent(QHideEvent *event);
	virtual void resizeEvent(QResizeEvent *event);
signals:
	// Notification to the previous stack entry that this window is
	// hidden.  Because the parent's show isn't called, when the child
	// is hidden.
	void hidden();
private slots:
	void TakeView();
	void Reloaded();
private:
	MinuteMonitor *View;
	// Don't destroy the child when it is hidden, just show it again...
	StackWindow *Child;
};

#endif // _STACK_WINDOW_H
